summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--chrome/browser/chromeos/webui/menu_ui.cc2
-rw-r--r--chrome/browser/extensions/extension_icon_manager.cc10
-rw-r--r--chrome/browser/extensions/extension_icon_manager.h2
-rw-r--r--chrome/browser/extensions/extension_menu_manager.h2
-rw-r--r--chrome/browser/extensions/extension_web_ui.cc2
-rw-r--r--chrome/browser/favicon_helper.cc6
-rw-r--r--chrome/browser/importer/importer.cc4
-rw-r--r--chrome/browser/search_engines/template_url.cc8
-rw-r--r--chrome/browser/tab_contents/render_view_context_menu.cc4
-rw-r--r--chrome/browser/ui/gtk/tabs/tab_renderer_gtk.cc22
-rw-r--r--chrome/browser/ui/touch/tabs/touch_tab.cc6
-rw-r--r--chrome/browser/ui/views/tab_icon_view.cc6
-rw-r--r--chrome/browser/ui/views/tabs/base_tab.cc6
-rw-r--r--chrome/browser/ui/views/tabs/side_tab.cc6
-rw-r--r--chrome/browser/ui/views/tabs/tab.cc12
-rw-r--r--chrome/renderer/render_view.cc2
-rw-r--r--ui/gfx/favicon_size.h10
-rw-r--r--views/controls/menu/menu_item_view_gtk.cc4
-rw-r--r--views/controls/table/native_table_win.cc2
-rw-r--r--views/controls/table/table_view.cc2
20 files changed, 59 insertions, 59 deletions
diff --git a/chrome/browser/chromeos/webui/menu_ui.cc b/chrome/browser/chromeos/webui/menu_ui.cc
index 66b9aeb..bbc5bb8 100644
--- a/chrome/browser/chromeos/webui/menu_ui.cc
+++ b/chrome/browser/chromeos/webui/menu_ui.cc
@@ -64,7 +64,7 @@ std::string GetFontShorthand(const gfx::Font* font) {
// used in webkit. Figure out the reason.
out.append(base::IntToString(font->GetFontSize() + 4));
out.append("px/");
- out.append(base::IntToString(std::max(kFavIconSize, font->GetHeight())));
+ out.append(base::IntToString(std::max(kFaviconSize, font->GetHeight())));
out.append("px \"");
out.append(UTF16ToUTF8(font->GetFontName()));
out.append("\",sans-serif");
diff --git a/chrome/browser/extensions/extension_icon_manager.cc b/chrome/browser/extensions/extension_icon_manager.cc
index f3db570..04966ac 100644
--- a/chrome/browser/extensions/extension_icon_manager.cc
+++ b/chrome/browser/extensions/extension_icon_manager.cc
@@ -54,7 +54,7 @@ void ExtensionIconManager::LoadIcon(const Extension* extension) {
pending_icons_.insert(extension->id());
image_tracker_.LoadImage(extension,
icon_resource,
- gfx::Size(kFavIconSize, kFavIconSize),
+ gfx::Size(kFaviconSize, kFaviconSize),
ImageLoadingTracker::CACHE);
}
}
@@ -68,8 +68,8 @@ const SkBitmap& ExtensionIconManager::GetIcon(const std::string& extension_id) {
result = &default_icon_;
}
DCHECK(result);
- DCHECK_EQ(kFavIconSize + padding_.width(), result->width());
- DCHECK_EQ(kFavIconSize + padding_.height(), result->height());
+ DCHECK_EQ(kFaviconSize + padding_.width(), result->width());
+ DCHECK_EQ(kFaviconSize + padding_.height(), result->height());
return *result;
}
@@ -106,10 +106,10 @@ void ExtensionIconManager::EnsureDefaultIcon() {
SkBitmap ExtensionIconManager::ApplyTransforms(const SkBitmap& source) {
SkBitmap result = source;
- if (result.width() != kFavIconSize || result.height() != kFavIconSize) {
+ if (result.width() != kFaviconSize || result.height() != kFaviconSize) {
result = skia::ImageOperations::Resize(
result, skia::ImageOperations::RESIZE_LANCZOS3,
- kFavIconSize, kFavIconSize);
+ kFaviconSize, kFaviconSize);
}
if (monochrome_) {
diff --git a/chrome/browser/extensions/extension_icon_manager.h b/chrome/browser/extensions/extension_icon_manager.h
index 41e01c3..6ce37a1 100644
--- a/chrome/browser/extensions/extension_icon_manager.h
+++ b/chrome/browser/extensions/extension_icon_manager.h
@@ -25,7 +25,7 @@ class ExtensionIconManager : public ImageLoadingTracker::Observer {
// Start loading the icon for the given extension.
void LoadIcon(const Extension* extension);
- // This returns a bitmap of width/height kFavIconSize, loaded either from an
+ // This returns a bitmap of width/height kFaviconSize, loaded either from an
// entry specified in the extension's 'icon' section of the manifest, or a
// default extension icon.
const SkBitmap& GetIcon(const std::string& extension_id);
diff --git a/chrome/browser/extensions/extension_menu_manager.h b/chrome/browser/extensions/extension_menu_manager.h
index 5e11f09..1834b41 100644
--- a/chrome/browser/extensions/extension_menu_manager.h
+++ b/chrome/browser/extensions/extension_menu_manager.h
@@ -240,7 +240,7 @@ class ExtensionMenuManager : public NotificationObserver {
const ContextMenuParams& params,
const ExtensionMenuItem::Id& menuItemId);
- // This returns a bitmap of width/height kFavIconSize, loaded either from an
+ // This returns a bitmap of width/height kFaviconSize, loaded either from an
// entry specified in the extension's 'icon' section of the manifest, or a
// default extension icon.
const SkBitmap& GetIconForExtension(const std::string& extension_id);
diff --git a/chrome/browser/extensions/extension_web_ui.cc b/chrome/browser/extensions/extension_web_ui.cc
index ec52de0..368541e 100644
--- a/chrome/browser/extensions/extension_web_ui.cc
+++ b/chrome/browser/extensions/extension_web_ui.cc
@@ -76,7 +76,7 @@ class ExtensionWebUIImageLoadingTracker : public ImageLoadingTracker::Observer {
ExtensionIconSet::MATCH_EXACTLY);
tracker_.LoadImage(extension_, icon_resource,
- gfx::Size(kFavIconSize, kFavIconSize),
+ gfx::Size(kFaviconSize, kFaviconSize),
ImageLoadingTracker::DONT_CACHE);
} else {
ForwardResult(NULL);
diff --git a/chrome/browser/favicon_helper.cc b/chrome/browser/favicon_helper.cc
index 27f8a64..68918ab 100644
--- a/chrome/browser/favicon_helper.cc
+++ b/chrome/browser/favicon_helper.cc
@@ -77,7 +77,7 @@ void FaviconHelper::SetFavicon(
const GURL& image_url,
const SkBitmap& image) {
const SkBitmap& sized_image =
- (image.width() == kFavIconSize && image.height() == kFavIconSize)
+ (image.width() == kFaviconSize && image.height() == kFaviconSize)
? image : ConvertToFaviconSize(image);
if (GetFaviconService() && ShouldSaveFavicon(url)) {
@@ -227,7 +227,7 @@ void FaviconHelper::DownloadFaviconOrAskHistory(NavigationEntry* entry) {
DCHECK(entry); // We should only get here if entry is valid.
if (favicon_expired_) {
// We have the mapping, but the favicon is out of date. Download it now.
- ScheduleDownload(entry->url(), entry->favicon().url(), kFavIconSize, NULL);
+ ScheduleDownload(entry->url(), entry->favicon().url(), kFaviconSize, NULL);
} else if (GetFaviconService()) {
// We don't know the favicon, but we may have previously downloaded the
// favicon for another page that shares the same favicon. Ask for the
@@ -274,7 +274,7 @@ void FaviconHelper::OnFaviconData(
if (!know_favicon || expired) {
// We don't know the favicon, or it is out of date. Request the current one.
- ScheduleDownload(entry->url(), entry->favicon().url(), kFavIconSize, NULL);
+ ScheduleDownload(entry->url(), entry->favicon().url(), kFaviconSize, NULL);
}
}
diff --git a/chrome/browser/importer/importer.cc b/chrome/browser/importer/importer.cc
index 74b2416..7bbc3df 100644
--- a/chrome/browser/importer/importer.cc
+++ b/chrome/browser/importer/importer.cc
@@ -30,12 +30,12 @@ bool Importer::ReencodeFavicon(const unsigned char* src_data,
size_t src_len,
std::vector<unsigned char>* png_data) {
// Decode the favicon using WebKit's image decoder.
- webkit_glue::ImageDecoder decoder(gfx::Size(kFavIconSize, kFavIconSize));
+ webkit_glue::ImageDecoder decoder(gfx::Size(kFaviconSize, kFaviconSize));
SkBitmap decoded = decoder.Decode(src_data, src_len);
if (decoded.empty())
return false; // Unable to decode.
- if (decoded.width() != kFavIconSize || decoded.height() != kFavIconSize) {
+ if (decoded.width() != kFaviconSize || decoded.height() != kFaviconSize) {
// The bitmap is not the correct size, re-sample.
int new_width = decoded.width();
int new_height = decoded.height();
diff --git a/chrome/browser/search_engines/template_url.cc b/chrome/browser/search_engines/template_url.cc
index 24c2f6b..ccdd594 100644
--- a/chrome/browser/search_engines/template_url.cc
+++ b/chrome/browser/search_engines/template_url.cc
@@ -654,7 +654,7 @@ void TemplateURL::SetFavIconURL(const GURL& url) {
for (std::vector<ImageRef>::iterator i = image_refs_.begin();
i != image_refs_.end(); ++i) {
if (i->type == "image/x-icon" &&
- i->width == kFavIconSize && i->height == kFavIconSize) {
+ i->width == kFaviconSize && i->height == kFaviconSize) {
if (!url.is_valid())
image_refs_.erase(i);
else
@@ -665,8 +665,8 @@ void TemplateURL::SetFavIconURL(const GURL& url) {
// Don't have one yet, add it.
if (url.is_valid()) {
add_image_ref(
- TemplateURL::ImageRef("image/x-icon", kFavIconSize,
- kFavIconSize, url));
+ TemplateURL::ImageRef("image/x-icon", kFaviconSize,
+ kFaviconSize, url));
}
}
@@ -674,7 +674,7 @@ GURL TemplateURL::GetFavIconURL() const {
for (std::vector<ImageRef>::const_iterator i = image_refs_.begin();
i != image_refs_.end(); ++i) {
if ((i->type == "image/x-icon" || i->type == "image/vnd.microsoft.icon")
- && i->width == kFavIconSize && i->height == kFavIconSize) {
+ && i->width == kFaviconSize && i->height == kFaviconSize) {
return i->url;
}
}
diff --git a/chrome/browser/tab_contents/render_view_context_menu.cc b/chrome/browser/tab_contents/render_view_context_menu.cc
index c9266a9..ccf0b34 100644
--- a/chrome/browser/tab_contents/render_view_context_menu.cc
+++ b/chrome/browser/tab_contents/render_view_context_menu.cc
@@ -401,8 +401,8 @@ void RenderViewContextMenu::SetExtensionIcon(const std::string& extension_id) {
DCHECK_GE(index, 0);
const SkBitmap& icon = menu_manager->GetIconForExtension(extension_id);
- DCHECK(icon.width() == kFavIconSize);
- DCHECK(icon.height() == kFavIconSize);
+ DCHECK(icon.width() == kFaviconSize);
+ DCHECK(icon.height() == kFaviconSize);
menu_model_.SetIcon(index, icon);
}
diff --git a/chrome/browser/ui/gtk/tabs/tab_renderer_gtk.cc b/chrome/browser/ui/gtk/tabs/tab_renderer_gtk.cc
index 1ae69ab4..c90984c 100644
--- a/chrome/browser/ui/gtk/tabs/tab_renderer_gtk.cc
+++ b/chrome/browser/ui/gtk/tabs/tab_renderer_gtk.cc
@@ -450,7 +450,7 @@ gfx::Size TabRendererGtk::GetMinimumUnselectedSize() {
// static
gfx::Size TabRendererGtk::GetMinimumSelectedSize() {
gfx::Size minimum_size = GetMinimumUnselectedSize();
- minimum_size.set_width(kLeftPadding + kFavIconSize + kRightPadding);
+ minimum_size.set_width(kLeftPadding + kFaviconSize + kRightPadding);
return minimum_size;
}
@@ -470,7 +470,7 @@ int TabRendererGtk::GetMiniWidth() {
int TabRendererGtk::GetContentHeight() {
// The height of the content of the Tab is the largest of the favicon,
// the title text and the close button graphic.
- int content_height = std::max(kFavIconSize, title_font_height_);
+ int content_height = std::max(kFaviconSize, title_font_height_);
return std::max(content_height, close_button_height_);
}
@@ -671,15 +671,15 @@ void TabRendererGtk::Layout() {
// Size the Favicon.
showing_icon_ = ShouldShowIcon();
if (showing_icon_) {
- int favicon_top = kTopPadding + (content_height - kFavIconSize) / 2;
+ int favicon_top = kTopPadding + (content_height - kFaviconSize) / 2;
favicon_bounds_.SetRect(local_bounds.x(), favicon_top,
- kFavIconSize, kFavIconSize);
+ kFaviconSize, kFaviconSize);
if ((mini() || data_.animating_mini_change) &&
bounds_.width() < kMiniTabRendererAsNormalTabWidth) {
int mini_delta = kMiniTabRendererAsNormalTabWidth - GetMiniWidth();
int ideal_delta = bounds_.width() - GetMiniWidth();
if (ideal_delta < mini_delta) {
- int ideal_x = (GetMiniWidth() - kFavIconSize) / 2;
+ int ideal_x = (GetMiniWidth() - kFaviconSize) / 2;
int x = favicon_bounds_.x() + static_cast<int>(
(1 - static_cast<float>(ideal_delta) /
static_cast<float>(mini_delta)) *
@@ -833,7 +833,7 @@ void TabRendererGtk::PaintIcon(gfx::Canvas* canvas) {
crashed_fav_icon->height(),
favicon_bounds_.x(),
favicon_bounds_.y() + fav_icon_hiding_offset_,
- kFavIconSize, kFavIconSize,
+ kFaviconSize, kFaviconSize,
true);
} else {
if (!data_.favicon.isNull()) {
@@ -847,9 +847,9 @@ void TabRendererGtk::PaintIcon(gfx::Canvas* canvas) {
// larger than the standard favicon.
int favIconHeightOffset = data_.app ? -2 : 0;
int favIconWidthDelta = data_.app ?
- data_.favicon.width() - kFavIconSize : 0;
+ data_.favicon.width() - kFaviconSize : 0;
int favIconHeightDelta = data_.app ?
- data_.favicon.height() - kFavIconSize : 0;
+ data_.favicon.height() - kFaviconSize : 0;
// TODO(pkasting): Use code in tab_icon_view.cc:PaintIcon() (or switch
// to using that class to render the favicon).
@@ -860,8 +860,8 @@ void TabRendererGtk::PaintIcon(gfx::Canvas* canvas) {
favicon_bounds_.y() + favIconHeightOffset
- favIconHeightDelta/2
+ fav_icon_hiding_offset_,
- kFavIconSize + favIconWidthDelta,
- kFavIconSize + favIconHeightDelta,
+ kFaviconSize + favIconWidthDelta,
+ kFaviconSize + favIconHeightDelta,
true);
}
}
@@ -979,7 +979,7 @@ void TabRendererGtk::PaintLoadingAnimation(gfx::Canvas* canvas) {
int TabRendererGtk::IconCapacity() const {
if (height() < GetMinimumUnselectedSize().height())
return 0;
- return (width() - kLeftPadding - kRightPadding) / kFavIconSize;
+ return (width() - kLeftPadding - kRightPadding) / kFaviconSize;
}
bool TabRendererGtk::ShouldShowCloseBox() const {
diff --git a/chrome/browser/ui/touch/tabs/touch_tab.cc b/chrome/browser/ui/touch/tabs/touch_tab.cc
index 69be10d..e2968c1 100644
--- a/chrome/browser/ui/touch/tabs/touch_tab.cc
+++ b/chrome/browser/ui/touch/tabs/touch_tab.cc
@@ -172,12 +172,12 @@ void TouchTab::PaintIcon(gfx::Canvas* canvas) {
if (base::i18n::IsRTL()) {
x = width() - x -
- (data().favicon.isNull() ? kFavIconSize : data().favicon.width());
+ (data().favicon.isNull() ? kFaviconSize : data().favicon.width());
}
int favicon_x = x;
- if (!data().favicon.isNull() && data().favicon.width() != kFavIconSize)
- favicon_x += (data().favicon.width() - kFavIconSize) / 2;
+ if (!data().favicon.isNull() && data().favicon.width() != kFaviconSize)
+ favicon_x += (data().favicon.width() - kFaviconSize) / 2;
if (data().network_state != TabRendererData::NETWORK_STATE_NONE) {
ThemeProvider* tp = GetThemeProvider();
diff --git a/chrome/browser/ui/views/tab_icon_view.cc b/chrome/browser/ui/views/tab_icon_view.cc
index 6ec77da..8b2e094 100644
--- a/chrome/browser/ui/views/tab_icon_view.cc
+++ b/chrome/browser/ui/views/tab_icon_view.cc
@@ -113,8 +113,8 @@ void TabIconView::PaintIcon(gfx::Canvas* canvas,
float float_src_w = static_cast<float>(src_w);
float float_src_h = static_cast<float>(src_h);
float scalable_w, scalable_h;
- if (src_w <= kFavIconSize && src_h <= kFavIconSize) {
- scalable_w = scalable_h = kFavIconSize;
+ if (src_w <= kFaviconSize && src_h <= kFaviconSize) {
+ scalable_w = scalable_h = kFaviconSize;
} else {
scalable_w = float_src_w;
scalable_h = float_src_h;
@@ -151,5 +151,5 @@ void TabIconView::OnPaint(gfx::Canvas* canvas) {
}
gfx::Size TabIconView::GetPreferredSize() {
- return gfx::Size(kFavIconSize, kFavIconSize);
+ return gfx::Size(kFaviconSize, kFaviconSize);
}
diff --git a/chrome/browser/ui/views/tabs/side_tab.cc b/chrome/browser/ui/views/tabs/side_tab.cc
index 89b0977..3046747 100644
--- a/chrome/browser/ui/views/tabs/side_tab.cc
+++ b/chrome/browser/ui/views/tabs/side_tab.cc
@@ -25,7 +25,7 @@ const SkColor kTextColor = SK_ColorBLACK;
const int kIconLeftPadding = 5;
// Location the title starts at.
-const int kTitleX = kIconLeftPadding + kFavIconSize + 5;
+const int kTitleX = kIconLeftPadding + kFaviconSize + 5;
};
////////////////////////////////////////////////////////////////////////////////
@@ -52,8 +52,8 @@ int SideTab::GetPreferredHeight() {
void SideTab::Layout() {
if (ShouldShowIcon()) {
- int icon_y = (height() - kFavIconSize) / 2;
- icon_bounds_.SetRect(kIconLeftPadding, icon_y, kFavIconSize, kFavIconSize);
+ int icon_y = (height() - kFaviconSize) / 2;
+ icon_bounds_.SetRect(kIconLeftPadding, icon_y, kFaviconSize, kFaviconSize);
} else {
icon_bounds_ = gfx::Rect();
}
diff --git a/chrome/browser/ui/views/tabs/tab.cc b/chrome/browser/ui/views/tabs/tab.cc
index 280e71c..0913d5b 100644
--- a/chrome/browser/ui/views/tabs/tab.cc
+++ b/chrome/browser/ui/views/tabs/tab.cc
@@ -143,7 +143,7 @@ gfx::Size Tab::GetMinimumUnselectedSize() {
// static
gfx::Size Tab::GetMinimumSelectedSize() {
gfx::Size minimum_size = GetMinimumUnselectedSize();
- minimum_size.set_width(kLeftPadding + kFavIconSize + kRightPadding);
+ minimum_size.set_width(kLeftPadding + kFaviconSize + kRightPadding);
return minimum_size;
}
@@ -227,7 +227,7 @@ void Tab::Layout() {
// The height of the content of the Tab is the largest of the favicon,
// the title text and the close button graphic.
- int content_height = std::max(kFavIconSize, font_height());
+ int content_height = std::max(kFaviconSize, font_height());
gfx::Size close_button_size(close_button()->GetPreferredSize());
content_height = std::max(content_height, close_button_size.height());
@@ -235,17 +235,17 @@ void Tab::Layout() {
showing_icon_ = ShouldShowIcon();
if (showing_icon_) {
// Use the size of the favicon as apps use a bigger favicon size.
- int favicon_top = kTopPadding + content_height / 2 - kFavIconSize / 2;
+ int favicon_top = kTopPadding + content_height / 2 - kFaviconSize / 2;
int favicon_left = lb.x();
favicon_bounds_.SetRect(favicon_left, favicon_top,
- kFavIconSize, kFavIconSize);
+ kFaviconSize, kFaviconSize);
if (data().mini && width() < kMiniTabRendererAsNormalTabWidth) {
// Adjust the location of the favicon when transitioning from a normal
// tab to a mini-tab.
int mini_delta = kMiniTabRendererAsNormalTabWidth - GetMiniWidth();
int ideal_delta = width() - GetMiniWidth();
if (ideal_delta < mini_delta) {
- int ideal_x = (GetMiniWidth() - kFavIconSize) / 2;
+ int ideal_x = (GetMiniWidth() - kFaviconSize) / 2;
int x = favicon_bounds_.x() + static_cast<int>(
(1 - static_cast<float>(ideal_delta) /
static_cast<float>(mini_delta)) *
@@ -607,7 +607,7 @@ SkBitmap Tab::DrawHoverGlowBitmap(int width_input, int height_input) {
int Tab::IconCapacity() const {
if (height() < GetMinimumUnselectedSize().height())
return 0;
- return (width() - kLeftPadding - kRightPadding) / kFavIconSize;
+ return (width() - kLeftPadding - kRightPadding) / kFaviconSize;
}
bool Tab::ShouldShowIcon() const {
diff --git a/chrome/renderer/render_view.cc b/chrome/renderer/render_view.cc
index 070a1ee..84a8be7 100644
--- a/chrome/renderer/render_view.cc
+++ b/chrome/renderer/render_view.cc
@@ -4042,7 +4042,7 @@ SkBitmap RenderView::ImageFromDataUrl(const GURL& url) const {
std::string mime_type, char_set, data;
if (net::DataURL::Parse(url, &mime_type, &char_set, &data) && !data.empty()) {
// Decode the favicon using WebKit's image decoder.
- webkit_glue::ImageDecoder decoder(gfx::Size(kFavIconSize, kFavIconSize));
+ webkit_glue::ImageDecoder decoder(gfx::Size(kFaviconSize, kFaviconSize));
const unsigned char* src_data =
reinterpret_cast<const unsigned char*>(&data[0]);
diff --git a/ui/gfx/favicon_size.h b/ui/gfx/favicon_size.h
index 5e9cd55..9d4cdbc 100644
--- a/ui/gfx/favicon_size.h
+++ b/ui/gfx/favicon_size.h
@@ -9,7 +9,7 @@
#include "base/compiler_specific.h"
// Size (along each axis) of the favicon.
-const int kFavIconSize = 16;
+const int kFaviconSize = 16;
// If the width or height is bigger than the favicon size, a new width/height
// is calculated and returned in width/height that maintains the aspect
@@ -18,14 +18,14 @@ static void calc_favicon_target_size(int* width, int* height) ALLOW_UNUSED;
// static
void calc_favicon_target_size(int* width, int* height) {
- if (*width > kFavIconSize || *height > kFavIconSize) {
+ if (*width > kFaviconSize || *height > kFaviconSize) {
// Too big, resize it maintaining the aspect ratio.
float aspect_ratio = static_cast<float>(*width) /
static_cast<float>(*height);
- *height = kFavIconSize;
+ *height = kFaviconSize;
*width = static_cast<int>(aspect_ratio * *height);
- if (*width > kFavIconSize) {
- *width = kFavIconSize;
+ if (*width > kFaviconSize) {
+ *width = kFaviconSize;
*height = static_cast<int>(*width / aspect_ratio);
}
}
diff --git a/views/controls/table/native_table_win.cc b/views/controls/table/native_table_win.cc
index fd7fb4b..aba9027 100644
--- a/views/controls/table/native_table_win.cc
+++ b/views/controls/table/native_table_win.cc
@@ -537,7 +537,7 @@ LRESULT NativeTableWin::OnCustomDraw(NMLVCUSTOMDRAW* draw_info) {
// view when they are 16x16 so we get an extra pixel of padding).
canvas.DrawBitmapInt(image, 0, 0,
image.width(), image.height(),
- 1, 1, kFavIconSize, kFavIconSize, true);
+ 1, 1, kFaviconSize, kFaviconSize, true);
// Only paint the visible region of the icon.
RECT to_draw = { intersection.left - icon_rect.left,
diff --git a/views/controls/table/table_view.cc b/views/controls/table/table_view.cc
index 59f5d62..fa2817f 100644
--- a/views/controls/table/table_view.cc
+++ b/views/controls/table/table_view.cc
@@ -1262,7 +1262,7 @@ LRESULT TableView::OnCustomDraw(NMLVCUSTOMDRAW* draw_info) {
// view when they are 16x16 so we get an extra pixel of padding).
canvas.DrawBitmapInt(image, 0, 0,
image.width(), image.height(),
- 1, 1, kFavIconSize, kFavIconSize, true);
+ 1, 1, kFaviconSize, kFaviconSize, true);
// Only paint the visible region of the icon.
RECT to_draw = { intersection.left - icon_rect.left,
diff --git a/chrome/browser/ui/views/tabs/base_tab.cc b/chrome/browser/ui/views/tabs/base_tab.cc
index 3ee7e76..91ed700 100644
--- a/chrome/browser/ui/views/tabs/base_tab.cc
+++ b/chrome/browser/ui/views/tabs/base_tab.cc
@@ -418,9 +418,9 @@ void BaseTab::PaintIcon(gfx::Canvas* canvas) {
if (bounds.IsEmpty())
return;
- // The size of bounds has to be kFavIconSize x kFavIconSize.
- DCHECK_EQ(kFavIconSize, bounds.width());
- DCHECK_EQ(kFavIconSize, bounds.height());
+ // The size of bounds has to be kFaviconSize x kFaviconSize.
+ DCHECK_EQ(kFaviconSize, bounds.width());
+ DCHECK_EQ(kFaviconSize, bounds.height());
bounds.set_x(GetMirroredXForRect(bounds));
diff --git a/views/controls/menu/menu_item_view_gtk.cc b/views/controls/menu/menu_item_view_gtk.cc
index 5991b9e..3c35a95 100644
--- a/views/controls/menu/menu_item_view_gtk.cc
+++ b/views/controls/menu/menu_item_view_gtk.cc
@@ -28,8 +28,8 @@ gfx::Size MenuItemView::CalculatePreferredSize() {
const gfx::Font& font = MenuConfig::instance().font;
// TODO(sky): this is a workaround until I figure out why font.height()
// isn't returning the right thing. We really only want to include
- // kFavIconSize if we're showing icons.
- int content_height = std::max(kFavIconSize, font.GetHeight());
+ // kFaviconSize if we're showing icons.
+ int content_height = std::max(kFaviconSize, font.GetHeight());
return gfx::Size(
font.GetStringWidth(title_) + label_start_ +
item_right_margin_ + GetChildPreferredWidth(),